@@ -561,6 +561,54 @@ gcm_calib_assistant_page_forward_cb (gint current_page, gpointer user_data)
 	return current_page;
 }
 
+/**
+ * gcm_calibrate_show_profile_location:
+ **/
+static void
+gcm_calibrate_show_profile_location (void)
+{
+	gboolean ret;
+	gchar *command_line;
+	GError *error = NULL;
+
+	/* just hardcode nautilus to open the folder */
+	command_line = g_strdup_printf ("nautilus %s/%s",
+					g_get_user_data_dir (),
+					"icc");
+	ret = g_spawn_command_line_async (command_line, &error);
+	if (!ret) {
+		g_warning ("failed to show profile: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+out:
+	g_free (command_line);
+}
+
+/**
+ * gcm_calibrate_is_livecd:
+ **/
+static gboolean
+gcm_calibrate_is_livecd (void)
+{
+	gboolean ret;
+	gchar *data = NULL;
+	GError *error = NULL;
+
+	/* get the kernel commandline */
+	ret = g_file_get_contents ("/proc/cmdline", &data, NULL, &error);
+	if (!ret) {
+		g_warning ("failed to get kernel command line: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	ret = g_strstr_len (data, -1, "liveimg") != NULL;
+out:
+	g_free (data);
+	return ret;
+}
+
 /**
  * gcm_calib_assistant_prepare_cb:
  **/
@@ -569,12 +617,18 @@ gcm_calib_assistant_prepare_cb (GtkAssistant *assistant,
 				GtkWidget *page_widget,
 				GcmCalibratePriv *calib)
 {
+	gboolean ret;
 	calib->current_page = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (page_widget),
 								   "GcmCalibrateMain::Index"));
 	switch (calib->current_page) {
 	case GCM_CALIBRATE_PAGE_LAST:
 		gcm_calib_device_uninihibit (calib);
 		gcm_calib_play_sound (calib);
+
+		/* show the user the profile to copy off the live system */
+		ret = gcm_calibrate_is_livecd ();
+		if (ret)
+			gcm_calibrate_show_profile_location ();
 		break;
 	case GCM_CALIBRATE_PAGE_ACTION:
 		g_debug ("lights! camera! action!");
@@ -769,6 +823,7 @@ gcm_calib_setup_page_intro (GcmCalibratePriv *calib)
 static void
 gcm_calib_setup_page_summary (GcmCalibratePriv *calib)
 {
+	gboolean ret;
 	GtkWidget *vbox;
 	GtkWidget *content;
 	GtkWidget *image;
@@ -1800,6 +1855,48 @@ gcm_calib_setup_page_failure (GcmCalibratePriv *calib)
 	gtk_widget_show_all (vbox);
 }
 
+/**
+ * gcm_calib_got_sensor:
+ **/
+static void
+gcm_calib_got_sensor (GcmCalibratePriv *calib, CdSensor *sensor)
+{
+	gboolean is_photospectrometer = FALSE;
+	gboolean ret;
+	GError *error = NULL;
+	GtkWidget *vbox;
+
+	/* connect to sensor */
+	ret = cd_sensor_connect_sync (sensor, NULL, &error);
+	if (!ret) {
+		g_warning ("failed to connect to sensor: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	calib->sensor = g_object_ref (sensor);
+	gcm_calibrate_set_sensor (calib->calibrate, sensor);
+
+	/* hide the prompt for the user to insert a sensor */
+	vbox = gcm_calib_get_vbox_for_page (calib,
+					    GCM_CALIBRATE_PAGE_SENSOR);
+	gtk_widget_hide (vbox);
+
+	/* if the device is a simple colorimeter, hide the temperature
+	 * chooser. Only expensive accurate spectrophotometers are
+	 * accurate enough to do a good job without a color cast */
+	if (cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_I1_PRO ||
+	    cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_COLOR_MUNKI ||
+	    cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_I1_DISPLAY3) {
+		is_photospectrometer = TRUE;
+	}
+	vbox = gcm_calib_get_vbox_for_page (calib,
+					    GCM_CALIBRATE_PAGE_DISPLAY_TEMPERATURE);
+	gtk_widget_set_visible (vbox, is_photospectrometer);
+out:
+	return;
+}
+
 /**
  * gcm_calib_get_sensors_cb:
  **/
@@ -1809,11 +1906,10 @@ gcm_calib_get_sensors_cb (GObject *object,
 			  gpointer user_data)
 {
 	CdClient *client = CD_CLIENT (object);
+	CdSensor *sensor_tmp;
 	GcmCalibratePriv *calib = (GcmCalibratePriv *) user_data;
 	GError *error = NULL;
 	GPtrArray *sensors;
-	GtkWidget *vbox;
-	gboolean ret;
 
 	/* get the result */
 	sensors = cd_client_get_sensors_finish (client, res, &error);
@@ -1824,22 +1920,10 @@ gcm_calib_get_sensors_cb (GObject *object,
 		goto out;
 	}
 
-	/* hide the sensors screen */
-	if (sensors->len > 0) {
-		calib->sensor = g_object_ref (g_ptr_array_index (sensors, 0));
-
-		ret = cd_sensor_connect_sync (calib->sensor, NULL, &error);
-		if (!ret) {
-			g_warning ("failed to connect to sensor: %s",
-				   error->message);
-			g_error_free (error);
-			goto out;
-		}
-
-		gcm_calibrate_set_sensor (calib->calibrate, calib->sensor);
-		vbox = gcm_calib_get_vbox_for_page (calib,
-						    GCM_CALIBRATE_PAGE_SENSOR);
-		gtk_widget_hide (vbox);
+	/* we've got a sensor */
+	if (sensors->len != 0) {
+		sensor_tmp = g_ptr_array_index (sensors, 0);
+		gcm_calib_got_sensor (calib, sensor_tmp);
 	}
 out:
 	if (sensors != NULL)
@@ -1918,13 +2002,9 @@ gcm_calib_add_pages (GcmCalibratePriv *calib)
 static void
 gcm_calib_sensor_added_cb (CdClient *client, CdSensor *sensor, GcmCalibratePriv *calib)
 {
-	GtkWidget *vbox;
-
 	g_debug ("sensor inserted");
-	calib->sensor = g_object_ref (sensor);
-	vbox = gcm_calib_get_vbox_for_page (calib,
-					    GCM_CALIBRATE_PAGE_SENSOR);
-	gtk_widget_hide (vbox);
+	gcm_calib_got_sensor (calib, sensor);
+	gtk_assistant_next_page (GTK_ASSISTANT (calib->main_window));
 }
 
 /**
